==> seedsui-react-5.7.84.tgz: package/lib/Cascader/DistrictModal/index.js <==
function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }
var _excluded = ["visible", "min", "submitProps", "value", "loadList", "loadData", "isCountry", "isProvince", "isCity", "isDistrict", "isStreet", "onBeforeSelect"];
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
function _defineProperty(obj, key, value) { key = _toPropertyKey(key); if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _toPropertyKey(arg) { var key = _toPrimitive(arg, "string"); return _typeof(key) === "symbol" ? key : String(key); }
function _toPrimitive(input, hint) { if (_typeof(input) !== "object" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || "default"); if (_typeof(res) !== "object") return res; throw new TypeError("@@toPrimitive must return a primitive value."); } return (hint === "string" ? String : Number)(input); }
function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }
function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }
function _iterableToArrayLimit(arr, i) { var _i = null == arr ? null : "undefined" != typeof Symbol && arr[Symbol.iterator] || arr["@@iterator"]; if (null != _i) { var _s, _e, _x, _r, _arr = [], _n = !0, _d = !1; try { if (_x = (_i = _i.call(arr)).next, 0 === i) { if (Object(_i) !== _i) return; _n = !1; } else for (; !(_n = (_s = _x.call(_i)).done) && (_arr.push(_s.value), _arr.length !== i); _n = !0); } catch (err) { _d = !0, _e = err; } finally { try { if (!_n && null != _i.return && (_r = _i.return(), Object(_r) !== _r)) return; } finally { if (_d) throw _e; } } return _arr; } }
function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
import React, { forwardRef, useEffect, useState } from 'react';
import { getMinTypes, matchType, testCity, testDistrict } from "./../DistrictMain/utils";

// 测试使用
// import BaseModal from 'seedsui-react/lib/Select/Modal'
// 内库使用
import BaseModal from "./../../Select/Modal";
import DistrictMain from "./../DistrictMain";

// 级联选择
import { jsx as _jsx } from "react/jsx-runtime";
var DistrictModal = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var visible = _ref.visible,
    _ref$min = _ref.min,
    min = _ref$min === void 0 ? '' : _ref$min,
    submitProps = _ref.submitProps,
    value = _ref.value,
    loadList = _ref.loadList,
    loadData = _ref.loadData,
    isCountry = _ref.isCountry,
    isProvince = _ref.isProvince,
    isCity = _ref.isCity,
    isDistrict = _ref.isDistrict,
    isStreet = _ref.isStreet,
    onBeforeSelect = _ref.onBeforeSelect,
    props = _objectWithoutProperties(_ref, _excluded);
  // 是否显示右上角确认按钮
  var _useState = useState(null),
    _useState2 = _slicedToArray(_useState, 2),
    submitVisible = _useState2[0],
    setSubmitVisible = _useState2[1];

  // 显示时更新
  useEffect(function () {
    if (visible) {
      updateSubmitVisible(value);
    }
    // eslint-disable-next-line
  }, [visible]);

  // 根据min判断是否显示确定按钮
  function updateSubmitVisible(tabs) {
    // 如果即没点击, 又没有传入初始值，则默认不显示提交按钮
    if (!Array.isArray(tabs) || !tabs.length) {
      setSubmitVisible(false);
      return;
    }
    submitVisible = null;

    // 选中的末级
    var lastTab = tabs[tabs.length - 1];

    // 获取末级类型
    var lastTabType = matchType(lastTab, {
      isCountry: isCountry,
      isProvince: isProvince,
      isCity: isCity,
      isDistrict: isDistrict,
      isStreet: isStreet
    });
    // 没有类型则可能是街道，如果上级是区或者市，则必定是街道
    if (!lastTabType && tabs.length > 2) {
      var prevTab = tabs[tabs.length - 2];
      if (testDistrict(prevTab, isDistrict)) {
        lastTabType = 'street';
      } else if (testCity(prevTab, isCity)) {
        lastTabType = 'street';
      }
    }

    // 最小支持的类型集合
    if (getMinTypes(min).includes(lastTabType)) {
      submitVisible = true;
    } else {
      submitVisible = false;
    }
    setSubmitVisible(submitVisible);
  }

  // 点击选项前判断是否指定类型: 省, 市, 区
  function handleBeforeSelect(tabs) {
    if (min) {
      updateSubmitVisible(tabs);
    }

    // 点击选项
    if (onBeforeSelect) return onBeforeSelect(tabs);
  }

  // 显示右上角的按钮
  // eslint-disable-next-line
  if (!submitProps) submitProps = {};
  if (submitVisible !== null) {
    // eslint-disable-next-line
    submitProps = _objectSpread({
      visible: submitVisible
    }, submitProps);
  }

  // 扩展非标准属性
  if (!props.MainProps) {
    props.MainProps = {};
  }
  props.MainProps.onBeforeSelect = handleBeforeSelect;
  props.MainProps.loadList = loadList;
  props.MainProps.loadData = loadData;
  return /*#__PURE__*/_jsx(BaseModal, _objectSpread(_objectSpread({
    ref: ref,
    visible: visible,
    value: value,
    submitProps: submitProps
  }, props), {}, {
    className: "cascader".concat(props.className ? ' ' + props.className : ''),
    MainComponent: DistrictMain
  }));
});
export default DistrictModal;

==> seedsui-react-5.7.88.tgz: package/lib/Cascader/DistrictModal/index.js <==
function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }
var _excluded = ["visible", "min", "submitProps", "value", "loadList", "loadData", "isCountry", "isProvince", "isMunicipality", "isCity", "isDistrict", "isStreet", "onDrillDown", "editableOptions"];
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
function _defineProperty(obj, key, value) { key = _toPropertyKey(key); if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _toPropertyKey(arg) { var key = _toPrimitive(arg, "string"); return _typeof(key) === "symbol" ? key : String(key); }
function _toPrimitive(input, hint) { if (_typeof(input) !== "object" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || "default"); if (_typeof(res) !== "object") return res; throw new TypeError("@@toPrimitive must return a primitive value."); } return (hint === "string" ? String : Number)(input); }
function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }
function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }
function _iterableToArrayLimit(arr, i) { var _i = null == arr ? null : "undefined" != typeof Symbol && arr[Symbol.iterator] || arr["@@iterator"]; if (null != _i) { var _s, _e, _x, _r, _arr = [], _n = !0, _d = !1; try { if (_x = (_i = _i.call(arr)).next, 0 === i) { if (Object(_i) !== _i) return; _n = !1; } else for (; !(_n = (_s = _x.call(_i)).done) && (_arr.push(_s.value), _arr.length !== i); _n = !0); } catch (err) { _d = !0, _e = err; } finally { try { if (!_n && null != _i.return && (_r = _i.return(), Object(_r) !== _r)) return; } finally { if (_d) throw _e; } } return _arr; } }
function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
import React, { forwardRef, useState } from 'react';
import { getMinTypes, matchType } from "./../DistrictMain/utils";

// 测试使用
// import BaseModal from 'seedsui-react/lib/Select/Modal'
// 内库使用
import BaseModal from "./../../Select/Modal";
import DistrictMain from "./../DistrictMain";

// 级联选择
import { jsx as _jsx } from "react/jsx-runtime";
var DistrictModal = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var visible = _ref.visible,
    _ref$min = _ref.min,
    min = _ref$min === void 0 ? '' : _ref$min,
    submitProps = _ref.submitProps,
    value = _ref.value,
    loadList = _ref.loadList,
    loadData = _ref.loadData,
    isCountry = _ref.isCountry,
    isProvince = _ref.isProvince,
    isMunicipality = _ref.isMunicipality,
    isCity = _ref.isCity,
    isDistrict = _ref.isDistrict,
    isStreet = _ref.isStreet,
    onDrillDown = _ref.onDrillDown,
    editableOptions = _ref.editableOptions,
    props = _objectWithoutProperties(_ref, _excluded);
  // 是否显示右上角确认按钮
  var _useState = useState(null),
    _useState2 = _slicedToArray(_useState, 2),
    submitVisible = _useState2[0],
    setSubmitVisible = _useState2[1];

  // 显示时更新
  // useEffect(() => {
  //   if (visible) {
  //     updateSubmitVisible(value)
  //   }
  //   // eslint-disable-next-line
  // }, [visible])

  // 根据min判断是否显示确定按钮
  function updateSubmitVisible(tabs, _ref2) {
    var data = _ref2.data;
    var submitVisible = null;

    // 获取末级类型
    var currentType = matchType(tabs, {
      data: data,
      isCountry: isCountry,
      isProvince: isProvince,
      isMunicipality: isMunicipality,
      isCity: isCity,
      isDistrict: isDistrict,
      isStreet: isStreet
    });

    // 最小支持的类型集合
    if (Array.isArray(currentType) && currentType.length && getMinTypes(min).some(function (minType) {
      return currentType.includes(minType);
    })) {
      submitVisible = true;
    } else {
      submitVisible = false;
    }
    setSubmitVisible(submitVisible);
  }

  // 点击选项前判断是否指定类型: 省, 市, 区
  function handleDrillDown(tabs, parameters) {
    if (min) {
      updateSubmitVisible(tabs, parameters);
    }

    // 点击选项
    if (onDrillDown) return onDrillDown(tabs, parameters);
  }

  // 显示右上角的按钮
  // eslint-disable-next-line
  if (!submitProps) submitProps = {};
  if (submitVisible !== null) {
    // eslint-disable-next-line
    submitProps = _objectSpread({
      visible: submitVisible
    }, submitProps);
  }

  // 扩展非标准属性
  if (!props.MainProps) {
    props.MainProps = {};
  }
  props.MainProps.onDrillDown = handleDrillDown;
  props.MainProps.loadList = loadList;
  props.MainProps.loadData = loadData;
  props.MainProps.editableOptions = editableOptions;
  return /*#__PURE__*/_jsx(BaseModal, _objectSpread(_objectSpread({
    ref: ref,
    visible: visible,
    value: value,
    submitProps: submitProps
  }, props), {}, {
    className: "cascader".concat(props.className ? ' ' + props.className : ''),
    MainComponent: DistrictMain
  }));
});
export default DistrictModal;
